<?php namespace GitSwag;

require_once("Preflight.php");

class Admin extends Preflight{

	// build the admin menu. 
	function AdminMenu(){
		add_options_page(
			$this->uc_class.' Settings', 
			$this->uc_class, 
			'administrator', 
			$this->lc_class, 
			array($this, 'AdminGetPage')
		);
	}

	// display a common header and menu for the admin page
	function AdminHeader(){
		
		?><h2><?php
		echo esc_attr(ucfirst($this->uc_class)); 
		?> Settings <?php 

		$query = null;

		if(isset($_GET[$this->lc_class.'_page'])){ 
			$query = $_GET[$this->lc_class.'_page'];
		}

		if(!empty($query)  
			&& is_array($this->Config['admin_pages']) 
			&& array_key_exists($query, $this->Config['admin_pages'])){ 
				?> - <?php
				echo esc_attr(ucfirst($this->Config['admin_pages'][$query]));
		}
		?></h2>
		<hr>
		<?php

		if(isset($this->Config['admin_pages'])){
			
			?><div class="admin-navigation"> Navigation: 

			<a href="?page=<?php 
			echo esc_attr($this->lc_class); 
			?>"><?php
			echo esc_attr($this->lc_class);
			?></a> | <?php

			foreach($this->Config['admin_pages'] as $key=>$admin_page){

				?><a href="?page=<?php 
				echo esc_attr($this->lc_class); 
				?>&<?php 
				echo esc_attr($this->lc_class.'_page='.$key); 
				?>"><?php 
				echo esc_attr($admin_page); 
				?></a> | <?php
			
			}
			?></div><hr><?php
		}
	}

	// display a footer (with donation link)
	function AdminFooter(){

		?>
		<hr>
		<div class="donatelink">
		Did you like this plugin? Please consider making a donation ;)
		<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
		<input type="hidden" name="cmd" value="_s-xclick">
		<input type="hidden" name="hosted_button_id" value="7RZTQXGBP4URG">
		<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
		<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
		</form>
		</div>
		<?php

	}

	function AdminInit(){
		// register setting from the config file if they exist
		if (current_user_can( 'manage_options' ) && isset($this->Config['init_settings'])){
			foreach($this->Config['init_settings'] as $setting){ 
		  		register_setting( $this->settings_group, $setting );
		  	}
		}
	}

	function AdminGetPage(){
		$this->AdminHeader();
		$this->AdminInterface();
		$this->AdminFooter();
	}

	
	// the default admin page
	function AdminInterface(){

		if (current_user_can( 'manage_options' )){

			/* POST process */
			if ((strtolower($_SERVER['REQUEST_METHOD']) === 'post') ) {

				if(isset($_POST['option_page']) && ($_POST['option_page'] === $this->settings_group)){
					update_option("username", $_POST['username']);								
				}

				$username = get_option('username');

				if(isset($_POST['delete_file']) && is_array($_POST['delete_file']) && (count($_POST['delete_file']))){
					
					foreach($_POST['delete_file'] as $file){

						$path = realpath(dirname(__FILE__)."/data/$username/$file");

						if(is_readable($path)){
							unlink($path);
							continue;
						}

						$path = realpath(dirname(__FILE__)."/data/gists/$file");
						
						if(is_readable($path)) unlink($path);
						
					}
				}
			}

			screen_icon(); ?>

			<style type="text/css">
			input{
				display:block;
			}
			</style>
			
			<form method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
			
			<?php
				settings_fields( $this->settings_group );
				do_settings_sections( $this->settings_group );
			?>
			
			<label for="username">Github Username</label>
			
			<input type="text" name="username" value="<?php 
				if($username = get_option('username')){
					echo esc_attr($username);				
				}else echo $this->user->user_login; 
			?>">

			<?php

			if(isset($username)){
				$this->DisplayCache($username);	
			}

			?>
			
			<?php
			submit_button("delete files/update username"); 
			?>

			</form><?php

			return;
		}
		
		wp_die();
		
	}

	private function DisplayCache($username){

		$path = realpath(dirname(__FILE__)."/data/$username");

		if(is_readable($path)){

			?>

			<ul><b>Cached Files:</b>

			<?php

			if($files = $this->find_all_files($username, $path)){

				$scanned_directory = array_filter($files, 'esc_attr');								
				
				foreach($scanned_directory as $element){
					
					?>

					<LI>

					<input 
					    type  = "checkbox" 
						name  = "delete_file[]" 
						value = "<?php echo $element['file']; ?>">

					<b>[<?php echo $element['file']; ?>]</b>
					
					- last updated 

					<?php echo $element['mtime']; ?>
					
					</LI>

					<?php
				}
			}
			else{

				?>

				<LI>(no files found)</LI>
				
				<?php
			}

			?>
			</ul>
			<?php

		}

		$path = realpath(dirname(__FILE__)."/data/gists");

		if(is_readable($path)){

			?>

			<ul><b>Cached Gists:</b>

			<?php

			if($files = $this->find_all_files('gists', $path)){ 

				$scanned_directory = array_filter($files, 'esc_attr');

				foreach($scanned_directory as $element){
					
					?>
					
					<LI>

					<input 
					    type  = "checkbox" 
						name  = "delete_file[]" 
						value = "<?php echo $element['file']; ?>">

					<b>[<?php echo $element['file']; ?>]</b>
					
					- last updated 
					
					<?php echo $element['mtime']; ?>
					
					</LI>

					<?php
				}
			}
			else{

				?>

				<LI>(no files found.)</LI>

				<?php
			
			}

			?>

			</ul>

			<?php
		}
	}

	private function find_all_files($username, $dir){

    	$root = scandir($dir);
    	
    	foreach($root as $value){
        	
        	if($value === '.' || $value === '..') {continue;}
        	
        	if(is_file("$dir/$value")) {
        		$path = "$dir/$value";
        		$base = substr($path, (stripos($path, $username)+strlen($username)+1));
        		$result[] = array('file'=>$base, 'mtime'=> date ("m/d/Y",filemtime($path))); continue;
        	}
        	
        	if($values = $this->find_all_files($username, "$dir/$value")){ 
        		foreach($values as $value){
            		$result[] = $value;
        		}
        	}
    	}
    	
    	return $result;
	} 

}